@@ -119,13 +119,16 @@ pub(super) struct RunningTest {
 }
 
 impl RunningTest {
-    fn message(&self, now: &Instant, width: usize, styles: &Styles) -> String {
-        let mut elapsed = (*now - self.start_time) - self.paused_for;
+    fn message(&self, now: Instant, width: usize, styles: &Styles) -> String {
+        let mut elapsed = (now - self.start_time).saturating_sub(self.paused_for);
         let status = match self.status {
             RunningTestStatus::Running => "     ".to_owned(),
             RunningTestStatus::Slow => " SLOW".style(styles.skip).to_string(),
             RunningTestStatus::Delay(d) => {
-                elapsed = d - elapsed;
+                // The elapsed might be greater than the delay duration in case
+                // we ticked past the delay duration without receiving a
+                // notification that the test retry started.
+                elapsed = d.saturating_sub(elapsed);
                 "DELAY".style(styles.retry).to_string()
             }
             RunningTestStatus::Retry => "RETRY".style(styles.retry).to_string(),
@@ -180,7 +183,6 @@ pub(super) struct ProgressBarState {
     hidden_no_capture: bool,
     hidden_run_paused: bool,
     hidden_info_response: bool,
-    hidden_between_sub_runs: bool,
 }
 
 impl ProgressBarState {
@@ -229,7 +231,6 @@ impl ProgressBarState {
             hidden_no_capture: false,
             hidden_run_paused: false,
             hidden_info_response: false,
-            hidden_between_sub_runs: false,
         }
     }
 
@@ -284,7 +285,7 @@ impl ProgressBarState {
             };
             for running_test in &running_tests[..count] {
                 msg.push('\n');
-                msg.push_str(&running_test.message(&now, width, styles));
+                msg.push_str(&running_test.message(now, width, styles));
             }
             if count < running_tests.len() {
                 let overflow_count = running_tests.len() - count;
@@ -312,23 +313,18 @@ impl ProgressBarState {
                 // Clear all test bars to remove empty lines of output between
                 // sub-runs.
                 self.bar.finish_and_clear();
-                // Hide the progress bar between sub runs to avoid a spurious
-                // progress bar.
-                self.hidden_between_sub_runs = true;
             }
             TestEventKind::SetupScriptStarted { no_capture, .. } => {
                 // Hide the progress bar if either stderr or stdout are being passed through.
                 if *no_capture {
                     self.hidden_no_capture = true;
                 }
-                self.hidden_between_sub_runs = false;
             }
             TestEventKind::SetupScriptFinished { no_capture, .. } => {
                 // Restore the progress bar if it was hidden.
                 if *no_capture {
                     self.hidden_no_capture = false;
                 }
-                self.hidden_between_sub_runs = false;
             }
             TestEventKind::TestStarted {
                 current_stats,
@@ -337,7 +333,6 @@ impl ProgressBarState {
                 ..
             } => {
                 self.running = *running;
-                self.hidden_between_sub_runs = false;
 
                 self.bar.set_prefix(progress_bar_prefix(
                     current_stats,
@@ -368,8 +363,6 @@ impl ProgressBarState {
                 self.running = *running;
                 self.remove_test(&test_instance.id());
 
-                self.hidden_between_sub_runs = false;
-
                 self.bar.set_prefix(progress_bar_prefix(
                     current_stats,
                     current_stats.cancel_reason,
@@ -439,12 +432,7 @@ impl ProgressBarState {
                 // continue to output to it.
                 self.hidden_run_paused = false;
                 let current_global_elapsed = self.bar.elapsed();
-
-                // `ProgressBar` is a lightweight handle and calling methods
-                // like `with_elapsed` on a clone also affects the original.
-                // Ideally there would be a `set_elapsed` method on self.bar,
-                // though.
-                self.bar.clone().with_elapsed(event.elapsed);
+                self.bar.set_elapsed(event.elapsed);
 
                 if let Some(running_tests) = &mut self.running_tests {
                     let delta = current_global_elapsed.saturating_sub(event.elapsed);
@@ -505,10 +493,7 @@ impl ProgressBarState {
     }
 
     fn should_hide(&self) -> bool {
-        self.hidden_no_capture
-            || self.hidden_run_paused
-            || self.hidden_info_response
-            || self.hidden_between_sub_runs
+        self.hidden_no_capture || self.hidden_run_paused || self.hidden_info_response
     }
 
     pub(super) fn is_hidden(&self) -> bool {
@@ -735,10 +720,11 @@ pub(super) fn write_summary_str(run_stats: &RunStats, styles: &Styles, out: &mut
         setup_scripts_timed_out: _,
         passed,
         passed_slow,
+        passed_timed_out: _,
         flaky,
         failed,
         failed_slow: _,
-        timed_out,
+        failed_timed_out,
         leaky,
         leaky_failed,
         exec_failed,
@@ -807,11 +793,11 @@ pub(super) fn write_summary_str(run_stats: &RunStats, styles: &Styles, out: &mut
         );
     }
 
-    if timed_out > 0 {
+    if failed_timed_out > 0 {
         swrite!(
             out,
             "{} {}, ",
-            timed_out.style(styles.count),
+            failed_timed_out.style(styles.count),
             "timed out".style(styles.fail),
         );
     }
@@ -948,6 +934,86 @@ mod tests {
         }
     }
 
+    #[test]
+    fn running_test_snapshots() {
+        let styles = Styles::default();
+        let now = Instant::now();
+
+        for (name, running_test) in running_test_examples(now) {
+            let msg = running_test.message(now, 80, &styles);
+            insta::assert_snapshot!(name, msg);
+        }
+    }
+
+    fn running_test_examples(now: Instant) -> Vec<(&'static str, RunningTest)> {
+        let binary_id = RustBinaryId::new("my-binary");
+        let test_name = "test::my_test".to_string();
+        let start_time = now - Duration::from_secs(125); // 2 minutes 5 seconds ago
+
+        vec![
+            (
+                "running_status",
+                RunningTest {
+                    binary_id: binary_id.clone(),
+                    test_name: test_name.clone(),
+                    status: RunningTestStatus::Running,
+                    start_time,
+                    paused_for: Duration::ZERO,
+                },
+            ),
+            (
+                "slow_status",
+                RunningTest {
+                    binary_id: binary_id.clone(),
+                    test_name: test_name.clone(),
+                    status: RunningTestStatus::Slow,
+                    start_time,
+                    paused_for: Duration::ZERO,
+                },
+            ),
+            (
+                "delay_status",
+                RunningTest {
+                    binary_id: binary_id.clone(),
+                    test_name: test_name.clone(),
+                    status: RunningTestStatus::Delay(Duration::from_secs(130)),
+                    start_time,
+                    paused_for: Duration::ZERO,
+                },
+            ),
+            (
+                "delay_status_underflow",
+                RunningTest {
+                    binary_id: binary_id.clone(),
+                    test_name: test_name.clone(),
+                    status: RunningTestStatus::Delay(Duration::from_secs(124)),
+                    start_time,
+                    paused_for: Duration::ZERO,
+                },
+            ),
+            (
+                "retry_status",
+                RunningTest {
+                    binary_id: binary_id.clone(),
+                    test_name: test_name.clone(),
+                    status: RunningTestStatus::Retry,
+                    start_time,
+                    paused_for: Duration::ZERO,
+                },
+            ),
+            (
+                "with_paused_duration",
+                RunningTest {
+                    binary_id: binary_id.clone(),
+                    test_name: test_name.clone(),
+                    status: RunningTestStatus::Running,
+                    start_time,
+                    paused_for: Duration::from_secs(30),
+                },
+            ),
+        ]
+    }
+
     fn run_stats_test_failure_examples() -> Vec<(&'static str, RunStats)> {
         vec![
             (
@@ -986,7 +1052,7 @@ mod tests {
                 RunStats {
                     initial_run_count: 20,
                     finished_count: 10,
-                    timed_out: 1,
+                    failed_timed_out: 1,
                     cancel_reason: Some(CancelReason::TestFailure),
                     ..RunStats::default()
                 },
